==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/item/weapon/Gungnir.java <==
package cc.thonly.reverie_dreams.item.weapon;

import cc.thonly.reverie_dreams.data.ModTags;
import cc.thonly.reverie_dreams.item.base.SwordItem;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1309;
import net.minecraft.class_1313;
import net.minecraft.class_1657;
import net.minecraft.class_1665;
import net.minecraft.class_1676;
import net.minecraft.class_1685;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1839;
import net.minecraft.class_1890;
import net.minecraft.class_1937;
import net.minecraft.class_2350;
import net.minecraft.class_2374;
import net.minecraft.class_243;
import net.minecraft.class_3218;
import net.minecraft.class_3414;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import net.minecraft.class_3468;
import net.minecraft.class_3489;
import net.minecraft.class_3532;
import net.minecraft.class_6880;
import net.minecraft.class_9463;
import net.minecraft.class_9701;
import net.minecraft.class_9886;

public class Gungnir extends SwordItem implements class_9463 {
    public static final class_9886 GUNGNIR = new class_9886(ModTags.BlockTypeTag.EMPTY, 1561, 8.0f, 5.5f, 10, class_3489.field_52387);

    public Gungnir(float attackDamage, float attackSpeed, class_1792.class_1793 settings) {
        super(GUNGNIR, attackDamage, attackSpeed, settings);
    }

    @Override
    public class_1839 method_7853(class_1799 stack) {
        return class_1839.field_8953;
    }

    @Override
    public int method_7881(class_1799 stack, class_1309 user) {
        return 72000;
    }

    @Override
    public boolean method_7840(class_1799 stack, class_1937 world, class_1309 user, int remainingUseTicks) {
        if (!(user instanceof class_1657 playerEntity)) {
            return false;
        }
        int i = this.method_7881(stack, user) - remainingUseTicks;
        if (i < 10) {
            return false;
        }
        float f = class_1890.method_60123(stack, playerEntity);
        if (f > 0.0f && !playerEntity.method_5721()) {
            return false;
        }
        if (stack.method_63692()) {
            return false;
        }
        class_6880<class_3414> registryEntry = class_1890.method_60165(stack, class_9701.field_51654).orElse(class_3417.field_15001);
        playerEntity.method_7259(class_3468.field_15372.method_14956(this));
        if (world instanceof class_3218 serverWorld) {
            stack.method_61653(1, playerEntity);
            if (f == 0.0f) {
                class_1799 itemStack = stack.method_60504(1, playerEntity);
                class_1685 tridentEntity = class_1676.method_61549(class_1685::new, serverWorld, itemStack, playerEntity, 0.0f, 2.5f, 1.0f);
                if (playerEntity.method_56992()) {
                    tridentEntity.field_7572 = class_1665.class_1666.field_7594;
                }
                world.method_43129(null, tridentEntity, registryEntry.comp_349(), class_3419.field_15248, 1.0f, 1.0f);
                return true;
            }
        }
        if (f > 0.0f) {
            float g = playerEntity.method_36454();
            float h = playerEntity.method_36455();
            float j = -class_3532.method_15374(g * ((float)Math.PI / 180)) * class_3532.method_15362(h * ((float)Math.PI / 180));
            float k = -class_3532.method_15374(h * ((float)Math.PI / 180));
            float l = class_3532.method_15362(g * ((float)Math.PI / 180)) * class_3532.method_15362(h * ((float)Math.PI / 180));
            float m = class_3532.method_15355(j * j + k * k + l * l);
            playerEntity.method_5762(j *= f / m, k *= f / m, l *= f / m);
            playerEntity.method_40126(20, 8.0f, stack);
            if (playerEntity.method_24828()) {
                float n = 1.1999999f;
                playerEntity.method_5784(class_1313.field_6308, new class_243(0.0, 1.1999999284744263, 0.0));
            }
            world.method_43129(null, playerEntity, registryEntry.comp_349(), class_3419.field_15248, 1.0f, 1.0f);
            return true;
        }
        return false;
    }

    @Override
    public class_1269 method_7836(class_1937 world, class_1657 user, class_1268 hand) {
        class_1799 itemStack = user.method_5998(hand);
        if (itemStack.method_63692()) {
            return class_1269.field_5814;
        }
        if (class_1890.method_60123(itemStack, user) > 0.0f && !user.method_5721()) {
            return class_1269.field_5814;
        }
        user.method_6019(hand);
        return class_1269.field_21466;
    }

    @Override
    public class_1676 method_58648(class_1937 world, class_2374 pos, class_1799 stack, class_2350 direction) {
        class_1685 tridentEntity = new class_1685(world, pos.method_10216(), pos.method_10214(), pos.method_10215(), stack.method_46651(1));
        tridentEntity.field_7572 = class_1665.class_1666.field_7593;
        return tridentEntity;
    }
}

==> reverie_dreams-0.4.7%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/item/weapon/Gungnir.java <==
package cc.thonly.reverie_dreams.item.weapon;

import cc.thonly.reverie_dreams.registry.tag.RDBlockTags;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1309;
import net.minecraft.class_1313;
import net.minecraft.class_1657;
import net.minecraft.class_1665;
import net.minecraft.class_1676;
import net.minecraft.class_1685;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1839;
import net.minecraft.class_1890;
import net.minecraft.class_1937;
import net.minecraft.class_2350;
import net.minecraft.class_2374;
import net.minecraft.class_243;
import net.minecraft.class_3218;
import net.minecraft.class_3414;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import net.minecraft.class_3468;
import net.minecraft.class_3489;
import net.minecraft.class_3532;
import net.minecraft.class_6880;
import net.minecraft.class_9463;
import net.minecraft.class_9701;
import net.minecraft.class_9886;
import cc.thonly.reverie_dreams.item.base.SwordItem;

public class Gungnir extends SwordItem implements class_9463 {
    public static final class_9886 GUNGNIR = new class_9886(RDBlockTags.EMPTY, 1561, 8.0f, 5.5f, 10, class_3489.field_52387);

    public Gungnir(float attackDamage, float attackSpeed, class_1792.class_1793 settings) {
        super(GUNGNIR, attackDamage, attackSpeed, settings);
    }

    @Override
    public class_1839 method_7853(class_1799 stack) {
        return class_1839.field_8953;
    }

    @Override
    public int method_7881(class_1799 stack, class_1309 user) {
        return 72000;
    }

    @Override
    public boolean method_7840(class_1799 stack, class_1937 world, class_1309 user, int remainingUseTicks) {
        if (!(user instanceof class_1657 playerEntity)) {
            return false;
        }
        int i = this.method_7881(stack, user) - remainingUseTicks;
        if (i < 10) {
            return false;
        }
        float f = class_1890.method_60123(stack, playerEntity);
        if (f > 0.0f && !playerEntity.method_5721()) {
            return false;
        }
        if (stack.method_63692()) {
            return false;
        }
        class_6880<class_3414> registryEntry = class_1890.method_60165(stack, class_9701.field_51654).orElse(class_3417.field_15001);
        playerEntity.method_7259(class_3468.field_15372.method_14956(this));
        if (world instanceof class_3218 serverWorld) {
            stack.method_61653(1, playerEntity);
            if (f == 0.0f) {
                class_1799 itemStack = stack.method_60504(1, playerEntity);
                class_1685 tridentEntity = class_1676.method_61549(class_1685::new, serverWorld, itemStack, playerEntity, 0.0f, 2.5f, 1.0f);
                if (playerEntity.method_56992()) {
                    tridentEntity.field_7572 = class_1665.class_1666.field_7594;
                }
                world.method_43129(null, tridentEntity, registryEntry.comp_349(), class_3419.field_15248, 1.0f, 1.0f);
                return true;
            }
        }
        if (f > 0.0f) {
            float g = playerEntity.method_36454();
            float h = playerEntity.method_36455();
            float j = -class_3532.method_15374(g * ((float)Math.PI / 180)) * class_3532.method_15362(h * ((float)Math.PI / 180));
            float k = -class_3532.method_15374(h * ((float)Math.PI / 180));
            float l = class_3532.method_15362(g * ((float)Math.PI / 180)) * class_3532.method_15362(h * ((float)Math.PI / 180));
            float m = class_3532.method_15355(j * j + k * k + l * l);
            playerEntity.method_5762(j *= f / m, k *= f / m, l *= f / m);
            playerEntity.method_40126(20, 8.0f, stack);
            if (playerEntity.method_24828()) {
                float n = 1.1999999f;
                playerEntity.method_5784(class_1313.field_6308, new class_243(0.0, 1.1999999284744263, 0.0));
            }
            world.method_43129(null, playerEntity, registryEntry.comp_349(), class_3419.field_15248, 1.0f, 1.0f);
            return true;
        }
        return false;
    }

    @Override
    public class_1269 method_7836(class_1937 world, class_1657 user, class_1268 hand) {
        class_1799 itemStack = user.method_5998(hand);
        if (itemStack.method_63692()) {
            return class_1269.field_5814;
        }
        if (class_1890.method_60123(itemStack, user) > 0.0f && !user.method_5721()) {
            return class_1269.field_5814;
        }
        user.method_6019(hand);
        return class_1269.field_21466;
    }

    @Override
    public class_1676 method_58648(class_1937 world, class_2374 pos, class_1799 stack, class_2350 direction) {
        class_1685 tridentEntity = new class_1685(world, pos.method_10216(), pos.method_10214(), pos.method_10215(), stack.method_46651(1));
        tridentEntity.field_7572 = class_1665.class_1666.field_7593;
        return tridentEntity;
    }
}
